Pavlov v0.1.2
Modules summary ↑
| Pavlov | The main Pavlov module |
| Pavlov.Callbacks | Allows running tasks in-between test executions. Currently only supports running tasks before tests are executed |
| Pavlov.Case | Use this module to prepare other modules for testing |
| Pavlov.Matchers | Provides several matcher functions.
Matchers accept up to two values, |
| Pavlov.Mocks | Use this module to mock methods on a given module |
| Pavlov.Mocks.Matchers | Provides matchers for Mocked modules |
| Pavlov.Syntax.Expect | Expect syntax for writing better specs |
| Pavlov.Syntax.Sugar | Provides an alternative DSL for BDD methods |